@@ -21,7 +21,7 @@ from paste.proxy import Proxy
 
 __author__ = "Roberto De Almeida <roberto@dealmeida.net>"
 __license__ = "MIT"
-__version__ = (0,1,1)
+__version__ = (0,1,3)
 
 
 def make_filter(app, global_conf, rulesets=None, config=None):
@@ -408,6 +408,10 @@ class RewriteMiddleware(object):
                         status = re.match("(?:R|redirect)(?:=(\d+))?",
                                 redir[-1]).group(1) or '302'
                         exception = status_code_to_exception(status)
+                        # Add query string to new location, since the WSGI
+                        # app doesn't seem to do this.
+                        if environ['QUERY_STRING']:
+                            new_path_info = '%s?%s' % (new_path_info, environ['QUERY_STRING'])
                         e = exception(new_path_info)
                         return e.wsgi_application(environ, new_start_response)
 
